@@ -4,7 +4,6 @@ pyLDAvis Prepare
 Main transformation functions for preparing LDAdata to the visualization's data structures
 """
 
-from __future__ import absolute_import
 from past.builtins import basestring
 from collections import namedtuple
 import json
@@ -14,7 +13,7 @@ import numpy as np
 import pandas as pd
 from scipy.stats import entropy
 from scipy.spatial.distance import pdist, squareform
-from .utils import NumPyEncoder
+from pyLDAvis.utils import NumPyEncoder
 try:
     from sklearn.manifold import MDS, TSNE
     sklearn_present = True
@@ -199,20 +198,20 @@ def _topic_coordinates(mds, topic_term_dists, topic_proportion, start_index=1):
     return mds_df
 
 
-def _chunks(l, n):
-    """ Yield successive n-sized chunks from l.
+def _chunks(lambda_seq, n):
+    """ Yield successive n-sized chunks from lambda_seq.
     """
-    for i in range(0, len(l), n):
-        yield l[i:i + n]
+    for i in range(0, len(lambda_seq), n):
+        yield lambda_seq[i:i + n]
 
 
-def _job_chunks(l, n_jobs):
+def _job_chunks(lambda_seq, n_jobs):
     n_chunks = n_jobs
     if n_jobs < 0:
         # so, have n chunks if we are using all n cores/cpus
         n_chunks = cpu_count() + 1 - n_jobs
 
-    return _chunks(l, n_chunks)
+    return _chunks(lambda_seq, n_chunks)
 
 
 def _find_relevance(log_ttd, log_lift, R, lambda_):
@@ -221,7 +220,7 @@ def _find_relevance(log_ttd, log_lift, R, lambda_):
 
 
 def _find_relevance_chunks(log_ttd, log_lift, R, lambda_seq):
-    return pd.concat([_find_relevance(log_ttd, log_lift, R, l) for l in lambda_seq])
+    return pd.concat([_find_relevance(log_ttd, log_lift, R, seq) for seq in lambda_seq])
 
 
 def _topic_info(topic_term_dists, topic_proportion, term_frequency, term_topic_freq,
@@ -230,10 +229,10 @@ def _topic_info(topic_term_dists, topic_proportion, term_frequency, term_topic_f
     term_proportion = term_frequency / term_frequency.sum()
 
     # compute the distinctiveness and saliency of the terms:
-    # this determines the R terms that are displayed when no topic is selected
+    # this determines the R terms that are displayed when no topic is selected.
     tt_sum = topic_term_dists.sum()
     topic_given_term = pd.eval("topic_term_dists / tt_sum")
-    log_1 = np.log(pd.eval("(topic_given_term.T / topic_proportion)"))
+    log_1 = np.log(pd.eval("topic_given_term.T / topic_proportion"))
     kernel = pd.eval("topic_given_term * log_1.T")
     distinctiveness = kernel.sum()
     saliency = term_proportion * distinctiveness
@@ -257,7 +256,7 @@ def _topic_info(topic_term_dists, topic_proportion, term_frequency, term_topic_f
 
     # compute relevance and top terms for each topic
     log_lift = np.log(pd.eval("topic_term_dists / term_proportion")).astype("float64")
-    log_ttd = np.log(topic_term_dists).astype("float64")
+    log_ttd = np.log(pd.eval("topic_term_dists")).astype("float64")
     lambda_seq = np.arange(0, 1 + lambda_step, lambda_step)
 
     def topic_top_term_df(tup):
@@ -269,7 +268,7 @@ def _topic_info(topic_term_dists, topic_proportion, term_frequency, term_topic_f
                            'Category': 'Topic%d' % new_topic_id,
                            'logprob': log_ttd.loc[original_topic_id, term_ix].round(4),
                            'loglift': log_lift.loc[original_topic_id, term_ix].round(4),
-                         })
+                           })
         return df.reindex(columns=[
             "Term", "Freq", "Total", "Category", "logprob", "loglift"
         ])
