@@ -10,7 +10,7 @@ import re
 import shutil
 import warnings
 import numpy as np
-from . import urls
+import pyLDAvis.urls
 
 # Make sure that DeprecationWarning gets printed
 warnings.simplefilter("always", DeprecationWarning)
@@ -22,9 +22,9 @@ def html_id_ok(objid, html5=False):
     If html5 == True, then use the more liberal html5 rules.
     """
     if html5:
-        return not re.search('\s', objid)
+        return not re.search(r'\s', objid)
     else:
-        return bool(re.match("^[a-zA-Z][a-zA-Z0-9\-\.\:\_]*$", objid))
+        return bool(re.match(r"^[a-zA-Z][a-zA-Z0-9\-\.\:\_]*$", objid))
 
 
 def get_id(obj, suffix="", prefix="el", warn_on_invalid=True):
@@ -83,11 +83,11 @@ def write_ipynb_local_js(location=None, d3_src=None, ldavis_src=None, ldavis_css
                 location = os.getcwd()
 
     if d3_src is None:
-        d3_src = urls.D3_LOCAL
+        d3_src = pyLDAvis.urls.D3_LOCAL
     if ldavis_src is None:
-        ldavis_src = urls.LDAVIS_LOCAL
+        ldavis_src = pyLDAvis.urls.LDAVIS_LOCAL
     if ldavis_css is None:
-        ldavis_css = urls.LDAVIS_CSS_LOCAL
+        ldavis_css = pyLDAvis.urls.LDAVIS_CSS_LOCAL
 
     d3js = os.path.basename(d3_src)
     ldavisjs = os.path.basename(ldavis_src)
